@@ -21,10 +21,14 @@ def modelmake(name, net, paramnames=None):
         net = eval(net)
     
     if paramnames is None:
-        Z = eval('(%s).Z(f)' % net)
-        paramnames = Z.symbols
-        paramnames.pop('t', None)
-        paramnames.pop('f', None)
+        try:
+            # For Lcapy 0.99
+            paramnames = net.params
+        except:
+            Z = eval('(%s).Z(f)' % net)
+            paramnames = Z.symbols
+            paramnames.pop('t', None)
+            paramnames.pop('f', None)
     
     params = ', '.join(paramnames)
     
@@ -71,10 +75,10 @@ class Model(object):
 
         return self._net.subs(vars(self)).Y.response(v, t)        
 
-    def draw(self, filename=None):
+    def draw(self, filename=None, layout='horizontal'):
         """Draw the network."""
 
-        self._net.draw(filename)
+        self._net.draw(filename, layout=layout)
 
     def _build(self, foo, name):
         paramnames = foo.symbols
