@@ -1,5 +1,5 @@
 #!/usr/bin/python3
-"""zfitpy V0.2
+"""zfitpy V0.3.2
 Copyright (c) 2021 Michael P. Hayes, UC ECE, NZ
 
 Usage: 
@@ -65,6 +65,7 @@ def main():
     parser.add_argument('--output_filename', type=str, help='output filename')
     parser.add_argument('--ranges', type=str, help="specify search ranges, e.g.,  {'R1':(0,1),'L1':(10,20)}")
     parser.add_argument('--draw', action='store_true', default=False, help='draw network')
+    parser.add_argument('--layout', type=str, default='horizontal', help='drawing layout: vertical, horizontal, ladder')    
     parser.add_argument('--show', action='store_true', default=False, help='show plot')
     parser.add_argument('--nyquist', action='store_true', default=False, help='use Nyquist plot')    
     parser.add_argument('--plot-error', action='store_true', default=False, help='plot impedance error')
@@ -75,10 +76,15 @@ def main():
     parser.add_argument('--method', type=str, help='optimization method: brute, trf, or dogbox', default='brute')    
     parser.add_argument('--steps', type=int, default=20,
                         help='the number of search steps per range')
+    parser.add_argument('--fmin', type=float, default=None,
+                        help='Minimum frequency to use for fitting')
+    parser.add_argument('--fmax', type=float, default=None,
+                        help='Maximum frequency to use for fitting')
+    parser.add_argument('--finish', type=str, help='finishing search method: none or fmin')
     parser.add_argument('--verbose', type=int, default=0, help='set verbosity 0-2')
     parser.add_argument('--pdb', action='store_true',
                         default=False,
-                        help="enter python debugger on exception")    
+                        help='enter python debugger on exception')    
     parser.add_argument('--style', type=str, help='matplotlib style filename')
 
     args = parser.parse_args()
@@ -92,7 +98,7 @@ def main():
     if args.draw:
         Model = model_make(args)
         model = Model()
-        model.draw(args.output_filename)
+        model.draw(args.output_filename, layout=args.layout)
 
         if args.show or args.output_filename is None:
             show()        
@@ -101,7 +107,9 @@ def main():
     if args.input_filename is None:
         raise ValueError('Impedance data not specified')
     
-    data = impedancedata(args.input_filename)
+    data = impedancedata(args.input_filename,
+                         fmin=args.fmin, fmax=args.fmax)
+
 
     if False and args.ranges is None:
         raise ValueError('Search ranges not specified')
@@ -117,7 +125,8 @@ def main():
         Model = model_make(args)
         zfitter = ZFitter(Model, data.f, data.Z)            
         fitmodel = zfitter(ranges=ranges, Ns=args.steps,
-                           method=args.method, verbose=args.verbose)
+                           method=args.method, verbose=args.verbose,
+                           finish=args.finish)
         print('%s, error=%.3e' % (fitmodel, fitmodel.error))
     
     plotter = Plotter()
