@@ -6,13 +6,14 @@ from .impedancedata import ImpedanceData, impedancedata
 from .model import modelmake, Model
 from .zfitter import ZFitter
 
-def zfit(data, model, ranges, Ns=10):
+def zfit(data, model, ranges, method='brute', opt='Z', **kwargs):
     """Fit impedance data to a model.
 
     `data` can be a filename string or and `ImpedanceData` object
     `model` can be a string describing the network model or a `Model` class
     `ranges` is a dictionary of the search ranges for each component
-    `Ns` is the number of search steps in each dimension.
+    `model` can be 'brute', 'trf', or 'dogbox'
+    `opt` can be `Y` for admittance fitting or `Z` for impedance fitting
 
     Returns: `ImpedanceData` object and a best-fit `Model` object.
     """
@@ -25,6 +26,6 @@ def zfit(data, model, ranges, Ns=10):
 
     zfitter = ZFitter(model, data.f, data.Z)
         
-    fitmodel = zfitter(ranges=ranges, Ns=Ns)
+    fitmodel = zfitter(ranges=ranges, method=method, opt=opt, **kwargs)
 
     return data, fitmodel
